@@ -1025,7 +1025,7 @@ sub TranslateCodedString($$$$)
         $$valPtr = $et->Decode($$valPtr, $$xlatPtr);
     } else {
         # don't yet support reading ISO 2022 shifted character sets
-        $et->WarnOnce('Some IPTC characters not converted (ISO 2022 shifting not supported)');
+        $et->Warn('Some IPTC characters not converted (ISO 2022 shifting not supported)');
     }
 }
 
@@ -1164,7 +1164,7 @@ sub ProcessIPTC($$$)
             }
             my $tableInfo = $tagTablePtr->{$rec};
             unless ($tableInfo) {
-                $et->WarnOnce("Unrecognized IPTC record $rec (ignored)");
+                $et->Warn("Unrecognized IPTC record $rec (ignored)");
                 $pos += $len;
                 next;   # ignore this entry
             }
@@ -1284,7 +1284,7 @@ image files.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
